nickva opened a new pull request, #6115:
URL: https://github.com/apache/couchdb/pull/6115

   Previously the sequence regex checker `"^\"?([0-9]+-)?(?<opaque>.*?)\"?$"` 
was 2-3 times slower than a simple matching and string module calls. A Q64 
sequence used to take 120usec to decode, and the new code takes 50usec. Q8 used 
to take 25usec, and now it takes 10usec (there is some time spent just setting 
up the re:run/1).
   
   Also, while at it add some extra validation when decoding: range types, use 
the recent `[safe]` flag. To ensure replaced nodes keep getting accepted, 
ensure to intern all the deleted `_nodes` doc IDs at node startup. Since we 
fixed it here also apply the same improvement to dreyfus bookmarks.
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]

Reply via email to